# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.projects_api import ProjectsApi  # noqa: E501


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_member_to_project(self):
        """Test case for add_member_to_project

        Addmembertoproject  # noqa: E501
        """
        pass

    def test_archive_project(self):
        """Test case for archive_project

        Archiveproject  # noqa: E501
        """
        pass

    def test_create_project(self):
        """Test case for create_project

        Createproject  # noqa: E501
        """
        pass

    def test_create_project_key(self):
        """Test case for create_project_key

        Createprojectkey  # noqa: E501
        """
        pass

    def test_create_usage_type(self):
        """Test case for create_usage_type

        Createusagetype  # noqa: E501
        """
        pass

    def test_delete_project_key(self):
        """Test case for delete_project_key

        Deleteprojectkey  # noqa: E501
        """
        pass

    def test_delete_usage_type(self):
        """Test case for delete_usage_type

        Deleteusagetype  # noqa: E501
        """
        pass

    def test_get_all_project_usage(self):
        """Test case for get_all_project_usage

        Getallprojectusage  # noqa: E501
        """
        pass

    def test_get_member_projects(self):
        """Test case for get_member_projects

        Getmemberprojects  # noqa: E501
        """
        pass

    def test_get_project(self):
        """Test case for get_project

        Getproject  # noqa: E501
        """
        pass

    def test_get_project_keys(self):
        """Test case for get_project_keys

        Getprojectkeys  # noqa: E501
        """
        pass

    def test_get_project_members(self):
        """Test case for get_project_members

        Getprojectmembers  # noqa: E501
        """
        pass

    def test_get_specific_project_usage(self):
        """Test case for get_specific_project_usage

        Getspecificprojectusage  # noqa: E501
        """
        pass

    def test_get_usage_type(self):
        """Test case for get_usage_type

        Getusagetype  # noqa: E501
        """
        pass

    def test_remove_member_from_project(self):
        """Test case for remove_member_from_project

        Removememberfromproject  # noqa: E501
        """
        pass

    def test_search_projects(self):
        """Test case for search_projects

        Searchprojects  # noqa: E501
        """
        pass

    def test_search_usage_type(self):
        """Test case for search_usage_type

        Searchusagetype  # noqa: E501
        """
        pass

    def test_update_project(self):
        """Test case for update_project

        Updateproject  # noqa: E501
        """
        pass

    def test_update_usage_type(self):
        """Test case for update_usage_type

        Updateusagetype  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
