# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.notes_api import NotesApi  # noqa: E501


class TestNotesApi(unittest.TestCase):
    """NotesApi unit test stubs"""

    def setUp(self):
        self.api = NotesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_note(self):
        """Test case for create_note

        Create Note  # noqa: E501
        """
        pass

    def test_delete_note(self):
        """Test case for delete_note

        Delete Note  # noqa: E501
        """
        pass

    def test_get_note(self):
        """Test case for get_note

        Get Note  # noqa: E501
        """
        pass

    def test_update_note(self):
        """Test case for update_note

        Update Note  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
