# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.default_api_endpoints.attach_entity_to_appointment import AttachEntityToAppointment
from ehelply_python_experimental_sdk.api.default_api_endpoints.attach_product_to_catalog import AttachProductToCatalog
from ehelply_python_experimental_sdk.api.default_api_endpoints.create_appointment import CreateAppointment
from ehelply_python_experimental_sdk.api.default_api_endpoints.create_catalog import CreateCatalog
from ehelply_python_experimental_sdk.api.default_api_endpoints.create_product import CreateProduct
from ehelply_python_experimental_sdk.api.default_api_endpoints.create_review import CreateReview
from ehelply_python_experimental_sdk.api.default_api_endpoints.delete_appointment import DeleteAppointment
from ehelply_python_experimental_sdk.api.default_api_endpoints.delete_catalog import DeleteCatalog
from ehelply_python_experimental_sdk.api.default_api_endpoints.delete_product import DeleteProduct
from ehelply_python_experimental_sdk.api.default_api_endpoints.delete_review import DeleteReview
from ehelply_python_experimental_sdk.api.default_api_endpoints.detach_entity_from_appointment import DetachEntityFromAppointment
from ehelply_python_experimental_sdk.api.default_api_endpoints.detach_product_from_catalog import DetachProductFromCatalog
from ehelply_python_experimental_sdk.api.default_api_endpoints.get_appointment import GetAppointment
from ehelply_python_experimental_sdk.api.default_api_endpoints.get_catalog import GetCatalog
from ehelply_python_experimental_sdk.api.default_api_endpoints.get_product import GetProduct
from ehelply_python_experimental_sdk.api.default_api_endpoints.get_review import GetReview
from ehelply_python_experimental_sdk.api.default_api_endpoints.search_appointment import SearchAppointment
from ehelply_python_experimental_sdk.api.default_api_endpoints.search_appointment_entities import SearchAppointmentEntities
from ehelply_python_experimental_sdk.api.default_api_endpoints.search_catalog_products import SearchCatalogProducts
from ehelply_python_experimental_sdk.api.default_api_endpoints.search_catalogs import SearchCatalogs
from ehelply_python_experimental_sdk.api.default_api_endpoints.search_entity_appointments import SearchEntityAppointments
from ehelply_python_experimental_sdk.api.default_api_endpoints.search_product import SearchProduct
from ehelply_python_experimental_sdk.api.default_api_endpoints.search_product_catalog import SearchProductCatalog
from ehelply_python_experimental_sdk.api.default_api_endpoints.search_reviews import SearchReviews
from ehelply_python_experimental_sdk.api.default_api_endpoints.update_appointment import UpdateAppointment
from ehelply_python_experimental_sdk.api.default_api_endpoints.update_catalog import UpdateCatalog
from ehelply_python_experimental_sdk.api.default_api_endpoints.update_product import UpdateProduct
from ehelply_python_experimental_sdk.api.default_api_endpoints.update_review import UpdateReview


class DefaultApi(
    AttachEntityToAppointment,
    AttachProductToCatalog,
    CreateAppointment,
    CreateCatalog,
    CreateProduct,
    CreateReview,
    DeleteAppointment,
    DeleteCatalog,
    DeleteProduct,
    DeleteReview,
    DetachEntityFromAppointment,
    DetachProductFromCatalog,
    GetAppointment,
    GetCatalog,
    GetProduct,
    GetReview,
    SearchAppointment,
    SearchAppointmentEntities,
    SearchCatalogProducts,
    SearchCatalogs,
    SearchEntityAppointments,
    SearchProduct,
    SearchProductCatalog,
    SearchReviews,
    UpdateAppointment,
    UpdateCatalog,
    UpdateProduct,
    UpdateReview,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
