# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.logging_api import LoggingApi  # noqa: E501


class TestLoggingApi(unittest.TestCase):
    """LoggingApi unit test stubs"""

    def setUp(self):
        self.api = LoggingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_logs(self):
        """Test case for get_logs

        Getlogs  # noqa: E501
        """
        pass

    def test_get_service_logs(self):
        """Test case for get_service_logs

        Getservicelogs  # noqa: E501
        """
        pass

    def test_get_subject_logs(self):
        """Test case for get_subject_logs

        Getsubjectlogs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
