# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.staff_api_endpoints.create_staff_places_staff_post import CreateStaffPlacesStaffPost
from ehelply_python_experimental_sdk.api.staff_api_endpoints.delete_staff_places_staff_staff_uuid_delete import DeleteStaffPlacesStaffStaffUuidDelete
from ehelply_python_experimental_sdk.api.staff_api_endpoints.get_staff_places_staff_staff_uuid_get import GetStaffPlacesStaffStaffUuidGet
from ehelply_python_experimental_sdk.api.staff_api_endpoints.search_staff_places_staff_get import SearchStaffPlacesStaffGet
from ehelply_python_experimental_sdk.api.staff_api_endpoints.update_staff_places_staff_staff_uuid_put import UpdateStaffPlacesStaffStaffUuidPut


class StaffApi(
    CreateStaffPlacesStaffPost,
    DeleteStaffPlacesStaffStaffUuidDelete,
    GetStaffPlacesStaffStaffUuidGet,
    SearchStaffPlacesStaffGet,
    UpdateStaffPlacesStaffStaffUuidPut,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
