# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.category_api import CategoryApi  # noqa: E501


class TestCategoryApi(unittest.TestCase):
    """CategoryApi unit test stubs"""

    def setUp(self):
        self.api = CategoryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_category_places_categories_post(self):
        """Test case for create_category_places_categories_post

        Create Category  # noqa: E501
        """
        pass

    def test_delete_category_places_categories_category_uuid_delete(self):
        """Test case for delete_category_places_categories_category_uuid_delete

        Delete Category  # noqa: E501
        """
        pass

    def test_get_category_places_categories_category_uuid_get(self):
        """Test case for get_category_places_categories_category_uuid_get

        Get Category  # noqa: E501
        """
        pass

    def test_search_categories_places_categories_get(self):
        """Test case for search_categories_places_categories_get

        Search Categories  # noqa: E501
        """
        pass

    def test_update_category_places_categories_category_uuid_put(self):
        """Test case for update_category_places_categories_category_uuid_put

        Update Category  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
