# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.acknowledge_alarm import AcknowledgeAlarm
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.assign_alarm import AssignAlarm
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.attach_alarm_note import AttachAlarmNote
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.attach_alarm_ticket import AttachAlarmTicket
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.clear_alarm import ClearAlarm
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_service import GetService
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_service_alarm import GetServiceAlarm
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_service_alarms import GetServiceAlarms
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_service_heartbeat import GetServiceHeartbeat
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_service_kpis import GetServiceKpis
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_service_spec import GetServiceSpec
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_service_specs import GetServiceSpecs
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_service_vitals import GetServiceVitals
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_services import GetServices
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.get_services_with_specs import GetServicesWithSpecs
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.hide_service import HideService
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.ignore_alarm import IgnoreAlarm
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.register_service import RegisterService
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.search_alarms import SearchAlarms
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.show_service import ShowService
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.terminate_alarm import TerminateAlarm
from ehelply_python_experimental_sdk.api.monitor_api_endpoints.trigger_alarm import TriggerAlarm


class MonitorApi(
    AcknowledgeAlarm,
    AssignAlarm,
    AttachAlarmNote,
    AttachAlarmTicket,
    ClearAlarm,
    GetService,
    GetServiceAlarm,
    GetServiceAlarms,
    GetServiceHeartbeat,
    GetServiceKpis,
    GetServiceSpec,
    GetServiceSpecs,
    GetServiceVitals,
    GetServices,
    GetServicesWithSpecs,
    HideService,
    IgnoreAlarm,
    RegisterService,
    SearchAlarms,
    ShowService,
    TerminateAlarm,
    TriggerAlarm,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
