# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.model.projects_usage_type_update import ProjectsUsageTypeUpdate
from ehelply_python_experimental_sdk import configuration


class TestProjectsUsageTypeUpdate(unittest.TestCase):
    """ProjectsUsageTypeUpdate unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
