# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.meta_api import MetaApi  # noqa: E501


class TestMetaApi(unittest.TestCase):
    """MetaApi unit test stubs"""

    def setUp(self):
        self.api = MetaApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_field(self):
        """Test case for create_field

        Create Field  # noqa: E501
        """
        pass

    def test_create_meta(self):
        """Test case for create_meta

        Create Meta  # noqa: E501
        """
        pass

    def test_delete_field(self):
        """Test case for delete_field

        Delete Field  # noqa: E501
        """
        pass

    def test_delete_meta(self):
        """Test case for delete_meta

        Delete Meta  # noqa: E501
        """
        pass

    def test_delete_meta_from_uuid(self):
        """Test case for delete_meta_from_uuid

        Delete Meta From Uuid  # noqa: E501
        """
        pass

    def test_get_field(self):
        """Test case for get_field

        Get Field  # noqa: E501
        """
        pass

    def test_get_meta(self):
        """Test case for get_meta

        Get Meta  # noqa: E501
        """
        pass

    def test_get_meta_from_uuid(self):
        """Test case for get_meta_from_uuid

        Get Meta From Uuid  # noqa: E501
        """
        pass

    def test_make_slug(self):
        """Test case for make_slug

        Make Slug  # noqa: E501
        """
        pass

    def test_touch_meta(self):
        """Test case for touch_meta

        Touch Meta  # noqa: E501
        """
        pass

    def test_update_field(self):
        """Test case for update_field

        Update Field  # noqa: E501
        """
        pass

    def test_update_meta(self):
        """Test case for update_meta

        Update Meta  # noqa: E501
        """
        pass

    def test_update_meta_from_uuid(self):
        """Test case for update_meta_from_uuid

        Update Meta From Uuid  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
