# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_entity_to_appointment(self):
        """Test case for attach_entity_to_appointment

        Attach Entity To Appointment  # noqa: E501
        """
        pass

    def test_attach_product_to_catalog(self):
        """Test case for attach_product_to_catalog

        Attach Product To Catalog  # noqa: E501
        """
        pass

    def test_create_appointment(self):
        """Test case for create_appointment

        Create Appointment  # noqa: E501
        """
        pass

    def test_create_catalog(self):
        """Test case for create_catalog

        Create Catalog  # noqa: E501
        """
        pass

    def test_create_product(self):
        """Test case for create_product

        Create Product  # noqa: E501
        """
        pass

    def test_create_review(self):
        """Test case for create_review

        Create Review  # noqa: E501
        """
        pass

    def test_delete_appointment(self):
        """Test case for delete_appointment

        Delete Appointment  # noqa: E501
        """
        pass

    def test_delete_catalog(self):
        """Test case for delete_catalog

        Delete Catalog  # noqa: E501
        """
        pass

    def test_delete_product(self):
        """Test case for delete_product

        Delete Product  # noqa: E501
        """
        pass

    def test_delete_review(self):
        """Test case for delete_review

        Delete Review  # noqa: E501
        """
        pass

    def test_detach_entity_from_appointment(self):
        """Test case for detach_entity_from_appointment

        Detach Entity From Appointment  # noqa: E501
        """
        pass

    def test_detach_product_from_catalog(self):
        """Test case for detach_product_from_catalog

        Detach Product From Catalog  # noqa: E501
        """
        pass

    def test_get_appointment(self):
        """Test case for get_appointment

        Get Appointment  # noqa: E501
        """
        pass

    def test_get_catalog(self):
        """Test case for get_catalog

        Get Catalog  # noqa: E501
        """
        pass

    def test_get_product(self):
        """Test case for get_product

        Get Product  # noqa: E501
        """
        pass

    def test_get_review(self):
        """Test case for get_review

        Get Review  # noqa: E501
        """
        pass

    def test_search_appointment(self):
        """Test case for search_appointment

        Search Appointment  # noqa: E501
        """
        pass

    def test_search_appointment_entities(self):
        """Test case for search_appointment_entities

        Search Appointment Entities  # noqa: E501
        """
        pass

    def test_search_catalog_products(self):
        """Test case for search_catalog_products

        Search Catalog Products  # noqa: E501
        """
        pass

    def test_search_catalogs(self):
        """Test case for search_catalogs

        Search Catalogs  # noqa: E501
        """
        pass

    def test_search_entity_appointments(self):
        """Test case for search_entity_appointments

        Get Entities Appointments  # noqa: E501
        """
        pass

    def test_search_product(self):
        """Test case for search_product

        Search Products  # noqa: E501
        """
        pass

    def test_search_product_catalog(self):
        """Test case for search_product_catalog

        Search Product Catalogs  # noqa: E501
        """
        pass

    def test_search_reviews(self):
        """Test case for search_reviews

        Search Review  # noqa: E501
        """
        pass

    def test_update_appointment(self):
        """Test case for update_appointment

        Update Appointment  # noqa: E501
        """
        pass

    def test_update_catalog(self):
        """Test case for update_catalog

        Update Catalog  # noqa: E501
        """
        pass

    def test_update_product(self):
        """Test case for update_product

        Update Product  # noqa: E501
        """
        pass

    def test_update_review(self):
        """Test case for update_review

        Update Review  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
