# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.users_api import UsersApi  # noqa: E501


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_confirm_signup(self):
        """Test case for confirm_signup

        Confirmsignup  # noqa: E501
        """
        pass

    def test_create_participant(self):
        """Test case for create_participant

        Createparticipant  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Createuser  # noqa: E501
        """
        pass

    def test_delete_participant(self):
        """Test case for delete_participant

        Deleteparticipant  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Deleteuser  # noqa: E501
        """
        pass

    def test_get_participant(self):
        """Test case for get_participant

        Getparticipant  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Getuser  # noqa: E501
        """
        pass

    def test_login(self):
        """Test case for login

        Login  # noqa: E501
        """
        pass

    def test_refresh_token(self):
        """Test case for refresh_token

        Refreshtoken  # noqa: E501
        """
        pass

    def test_reset_password(self):
        """Test case for reset_password

        Resetpassword  # noqa: E501
        """
        pass

    def test_reset_password_confirmation(self):
        """Test case for reset_password_confirmation

        Resetpasswordconfirmation  # noqa: E501
        """
        pass

    def test_search_participants(self):
        """Test case for search_participants

        Searchparticipants  # noqa: E501
        """
        pass

    def test_signup(self):
        """Test case for signup

        Signup  # noqa: E501
        """
        pass

    def test_update_participant(self):
        """Test case for update_participant

        Updateparticipant  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Updateuser  # noqa: E501
        """
        pass

    def test_user_validations(self):
        """Test case for user_validations

        Uservalidations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
