# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.projects_api_endpoints.add_member_to_project import AddMemberToProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.archive_project import ArchiveProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project import CreateProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project_key import CreateProjectKey
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_usage_type import CreateUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.delete_project_key import DeleteProjectKey
from ehelply_python_experimental_sdk.api.projects_api_endpoints.delete_usage_type import DeleteUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_all_project_usage import GetAllProjectUsage
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_member_projects import GetMemberProjects
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project import GetProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_keys import GetProjectKeys
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_members import GetProjectMembers
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_specific_project_usage import GetSpecificProjectUsage
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_usage_type import GetUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.remove_member_from_project import RemoveMemberFromProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.search_projects import SearchProjects
from ehelply_python_experimental_sdk.api.projects_api_endpoints.search_usage_type import SearchUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.update_project import UpdateProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.update_usage_type import UpdateUsageType


class ProjectsApi(
    AddMemberToProject,
    ArchiveProject,
    CreateProject,
    CreateProjectKey,
    CreateUsageType,
    DeleteProjectKey,
    DeleteUsageType,
    GetAllProjectUsage,
    GetMemberProjects,
    GetProject,
    GetProjectKeys,
    GetProjectMembers,
    GetSpecificProjectUsage,
    GetUsageType,
    RemoveMemberFromProject,
    SearchProjects,
    SearchUsageType,
    UpdateProject,
    UpdateUsageType,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
