# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.staff_api import StaffApi  # noqa: E501


class TestStaffApi(unittest.TestCase):
    """StaffApi unit test stubs"""

    def setUp(self):
        self.api = StaffApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_staff_places_staff_post(self):
        """Test case for create_staff_places_staff_post

        Create Staff  # noqa: E501
        """
        pass

    def test_delete_staff_places_staff_staff_uuid_delete(self):
        """Test case for delete_staff_places_staff_staff_uuid_delete

        Delete Staff  # noqa: E501
        """
        pass

    def test_get_staff_places_staff_staff_uuid_get(self):
        """Test case for get_staff_places_staff_staff_uuid_get

        Get Staff  # noqa: E501
        """
        pass

    def test_search_staff_places_staff_get(self):
        """Test case for search_staff_places_staff_get

        Search Staff  # noqa: E501
        """
        pass

    def test_update_staff_places_staff_staff_uuid_put(self):
        """Test case for update_staff_places_staff_staff_uuid_put

        Update Staff  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
